package com.perforce.hws.swagger.models;

import com.google.common.base.CaseFormat;
import io.swagger.models.Model;
import io.swagger.models.ModelImpl;
import io.swagger.models.properties.Property;

import java.util.List;
import java.util.stream.Collectors;

/**
 * Created by tristan on 4/13/16.
 */
public class Definition {

    private String id;
    private Model model;

    public Definition(String id, Model model) {
        this.id = id;
        this.model = model;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Model getModel() {
        return model;
    }

    public void setModel(Model model) {
        this.model = model;
    }

    public String getIdRef() {
        return CaseFormat.UPPER_CAMEL.converterTo(CaseFormat.LOWER_HYPHEN).convert(id);
    }

    public String getJsFileBaseName() {
        return CaseFormat.UPPER_CAMEL.converterTo(CaseFormat.LOWER_UNDERSCORE).convert(id);
    }

    public String getJsFileName() {
        return getJsFileBaseName() + ".js";
    }

    public List<PropertyHelper> getPropertyHelpers() {
        return model.getProperties().entrySet().stream()
                .map(e -> new PropertyHelper(e.getKey(), e.getValue()))
                .collect(Collectors.toList());
    }

    public boolean hasAdditionalProperties() {
        if (model instanceof ModelImpl) {
            ModelImpl impl = (ModelImpl)model;
            return impl.getAdditionalProperties() != null;
        }
        return false;
    }

    public Property getAdditionalProperties() {
        if (model instanceof ModelImpl) {
            ModelImpl modelImpl = (ModelImpl)model;
            return modelImpl.getAdditionalProperties();
        }
        return null;
    }
}
